@@ -7,15 +7,16 @@ from pathlib import Path
 from types import TracebackType
 from typing import List, Optional, Type, TypeVar
 
-from handsdown.settings import ENCODING
-from handsdown.utils import extract_md_title
+from handsdown.constants import ENCODING
 from handsdown.utils.indent_trimmer import IndentTrimmer
+from handsdown.utils.nice_path import NicePath
 from handsdown.utils.path_finder import PathFinder
+from handsdown.utils.strings import extract_md_title
 
 __all__ = ["MDDocument"]
 
 
-_MDDocument = TypeVar("_MDDocument", bound="MDDocument")
+_R = TypeVar("_R", bound="MDDocument")
 
 
 class MDDocument:
@@ -30,7 +31,6 @@ class MDDocument:
         md_doc.append('## New section')
         md_doc.append('some content')
         md_doc.title = 'My doc'
-        md_doc.add_toc_if_not_exists()
         md_doc.write()
 
         # output is indented for readability
@@ -54,9 +54,6 @@ class MDDocument:
         path -- Path to store document.
     """
 
-    # Indent in spaces for nested ToC lines
-    TOC_INDENT = 4
-
     _anchor_re = re.compile(r"[^a-z0-9_-]+")
     _escape_title_re = re.compile(r"(_+\S+_+)$")
     _section_separator = "\n\n"
@@ -67,9 +64,10 @@ class MDDocument:
         self._title = ""
         self._subtitle = ""
         self._toc_section = ""
-        self._path = path
+        self._path = NicePath(path)
         self.path_finder = PathFinder(self._path.parent)
         self._encoding = encoding
+        self.source_code_url = ""
 
     def __enter__(self) -> "MDDocument":
         return self
@@ -85,7 +83,14 @@ class MDDocument:
             raise exc_value
         return self.write()
 
-    def read(self, source_path: Optional[Path] = None) -> None:
+    @property
+    def source_file_name(self) -> str:
+        """
+        Source cide file name.
+        """
+        return self.source_code_url.split("/")[-1]
+
+    def read(self, path: Path) -> None:
         """
         Read and parse content from `source_path`.
 
@@ -93,7 +98,6 @@ class MDDocument:
             source_path -- Input file path. If not provided - `path` is used.
             encoding -- File encoding.
         """
-        path = source_path or self._path
         self._content = path.read_text(encoding=self._encoding)
         self._title = ""
         self._toc_section = ""
@@ -120,13 +124,6 @@ class MDDocument:
         if not self._subtitle and self._sections and not self._sections[0].startswith("#"):
             self._subtitle = self._sections.pop(0)
 
-    def add_toc_if_not_exists(self) -> None:
-        """
-        Check if ToC exists in the document or create one.
-        """
-        if not self._toc_section:
-            self._toc_section = self.generate_toc_section()
-
     @classmethod
     def get_anchor(cls, title: str) -> str:
         """
@@ -178,25 +175,6 @@ class MDDocument:
         """
         return f"[{title}]({link})"
 
-    def render_md_doc_link(
-        self: _MDDocument, target_md_document: _MDDocument, title: Optional[str] = None
-    ) -> str:
-        """
-        Render Markdown link to `target_md_document` header path with a correct title.
-
-        Arguments:
-            target_md_document -- Target `MDDocument`.
-            title -- Link text. If not provided `target_md_document.title` is used.
-
-        Returns:
-            A string with Markdown link.
-        """
-        return self.render_doc_link(
-            title=title or target_md_document.title,
-            anchor=self.get_anchor(target_md_document.title),
-            target_path=target_md_document.path,
-        )
-
     def render_doc_link(
         self, title: str, anchor: str = "", target_path: Optional[Path] = None
     ) -> str:
@@ -231,14 +209,33 @@ class MDDocument:
             A string with Markdown link.
         """
         link = ""
-        if anchor:
-            link = f"#{anchor}"
         if target_path and target_path != self._path:
             link_path = self.path_finder.relative(target_path)
-            link = f"{link_path.as_posix()}{link}"
+            link = f"{link}{link_path.as_posix()}"
+        if anchor:
+            link = f"{link}#{anchor}"
 
         return self.render_link(title, link)
 
+    def get_doc_link(self, path: Path, anchor: str = "") -> str:
+        """
+        Get Markdown link to a local MD document, use relative path as a link.
+
+        Arguments:
+            path -- Path to local MDDocument
+            anchor -- Unescaped or escaped anchor tag
+
+        Returns:
+            A string with Markdown link.
+        """
+        link = ""
+        if path and path != self.path:
+            link_path = self.path_finder.relative(path)
+            link = f"{link}{link_path.as_posix()}"
+        if anchor:
+            link = f"{link}#{anchor}"
+        return link
+
     def _build_content(self) -> str:
         sections = []
         if self._title:
@@ -303,7 +300,7 @@ class MDDocument:
         return self._sections
 
     @property
-    def path(self) -> Path:
+    def path(self) -> NicePath:
         """
         Output path of the document.
         """
@@ -330,84 +327,6 @@ class MDDocument:
 
         self._content = self._build_content()
 
-    def append_title(self, title: str, level: int) -> None:
-        """
-        Append `title` of a given `level` to the document.
-
-        Handle trimming and sectioning the content and update
-        `title` and `toc_section` fields.
-
-        Arguments:
-            title -- Title to add.
-            level -- Title level, number of `#` symbols.
-        """
-        section_level = "#" * level
-        section = f"{section_level} {self._escape_title(title)}"
-        self._sections.append(section)
-        self._content = self._build_content()
-
-    def generate_toc_section(self, max_depth: int = 3) -> str:
-        """
-        Generate Table of Contents MD content.
-
-        Arguments:
-            max_depth -- Add headers to ToC only up to this level.
-
-        Returns:
-            A string with ToC.
-        """
-        toc_lines = []
-        if self.title:
-            link = self.render_doc_link(self.title, anchor=self.get_anchor(self.title))
-            toc_line = self.get_toc_line(link, level=0)
-            toc_lines.append(toc_line)
-
-        sections = [self.title, self.subtitle] + self.sections
-        for section in sections:
-            if not section.startswith("#"):
-                continue
-
-            if "\n" in section:
-                continue
-
-            if "# " not in section:
-                continue
-
-            section = section.rstrip()
-
-            header_symbols, title = section.split(" ", 1)
-            title = title.strip()
-            if not title:
-                continue
-
-            if header_symbols.replace("#", ""):
-                continue
-
-            header_level = len(header_symbols)
-            if header_level > max_depth:
-                continue
-
-            link = self.render_doc_link(title, anchor=self.get_anchor(title))
-            toc_line = self.get_toc_line(link, level=header_level - 1)
-            toc_lines.append(toc_line)
-
-        return "\n".join(toc_lines)
-
-    @classmethod
-    def get_toc_line(cls, line: str, level: int = 0) -> str:
-        """
-        Get ToC `line` of given `level`.
-
-        Arguments:
-            line -- Line to prepare.
-            level -- Line level, starts with `0`.
-
-        Returns:
-            Ready to insert ToC line.
-        """
-        indent = cls.TOC_INDENT * level
-        return IndentTrimmer.indent_line(f"- {line}", indent)
-
     @classmethod
     def _escape_title(cls, title: str) -> str:
         for match in cls._escape_title_re.findall(title):
