@@ -6,15 +6,14 @@ Supports `.gitignore`-like `include` and `exclude` patterns.
 
 import fnmatch
 from pathlib import Path
-from typing import Iterable, Iterator, List
+from typing import Iterable, Iterator, List, TypeVar
 
-__all__ = ["PathFinder", "PathFinderError"]
+from handsdown.exceptions import PathFinderError
+from handsdown.utils.nice_path import NicePath
 
+_R = TypeVar("_R", bound="PathFinder")
 
-class PathFinderError(Exception):
-    """
-    Main error for `PathFinder`.
-    """
+__all__ = ["PathFinder"]
 
 
 class PathFinder:
@@ -57,13 +56,13 @@ class PathFinder:
         self.include_exprs: List[str] = []
         self.exclude_exprs: List[str] = []
 
-    def _copy(self, include_exprs: Iterable[str], exclude_exprs: Iterable[str]) -> "PathFinder":
-        new_copy = PathFinder(self._root)
+    def _copy(self: _R, include_exprs: Iterable[str], exclude_exprs: Iterable[str]) -> _R:
+        new_copy = self.__class__(self._root)
         new_copy.include_exprs = list(include_exprs)
         new_copy.exclude_exprs = list(exclude_exprs)
         return new_copy
 
-    def include(self, *fn_exrps: str) -> "PathFinder":
+    def include(self: _R, *fn_exrps: str) -> _R:
         """
         Add `fnmatch` expression to white list.
 
@@ -84,7 +83,7 @@ class PathFinder:
             include_exprs.append(fn_exrp)
         return self._copy(include_exprs=include_exprs, exclude_exprs=self.exclude_exprs)
 
-    def exclude(self, *fn_exrps: str) -> "PathFinder":
+    def exclude(self: _R, *fn_exrps: str) -> _R:
         """
         Add `fnmatch` expression to black list.
 
@@ -127,7 +126,7 @@ class PathFinder:
 
         return False
 
-    def glob(self, glob_expr: str) -> Iterator[Path]:
+    def glob(self, glob_expr: str) -> Iterator[NicePath]:
         """
         Find all matching `Path` objects respecting `include` and `exclude` patterns.
 
@@ -141,9 +140,9 @@ class PathFinder:
             if self._match_exclude(relative_path):
                 continue
 
-            yield path
+            yield NicePath(path)
 
-    def relative(self, target: Path) -> Path:
+    def relative(self, target: Path) -> NicePath:
         """
         Find a relative path from `root` to `target`.
 
@@ -156,7 +155,7 @@ class PathFinder:
             A relative path to `target`.
         """
         if not target.is_absolute():
-            raise PathFinderError("Target path should be absolute")
+            raise PathFinderError(f"Target path should be absolute, got {target}")
 
         relative_target = Path()
         up_path = Path()
@@ -170,7 +169,7 @@ class PathFinder:
             else:
                 break
 
-        return up_path / relative_target
+        return NicePath(up_path) / relative_target
 
     def mkdir(self, force: bool = False) -> None:
         """
